# {{ project }}

[![readthedocs](https://shields.io/readthedocs/{{ project }})](https://{{ project }}.readthedocs.io)
[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/{{ user }}/{{ project }}/main.svg)](https://results.pre-commit.ci/latest/github/{{ user }}/{{ project }}/main)
[![github/workflow](https://github.com/{{ user }}/{{ project }}/actions/workflows/main.yml/badge.svg)](https://github.com/{{ user }}/{{ project }}/actions)
[![codecov](https://codecov.io/gh/{{ user }}/{{ project }}/branch/main/graph/badge.svg)](https://codecov.io/gh/{{ user }}/{{ project }})
[![DeepSource](https://deepsource.io/gh/{{ user }}/{{ project }}.svg/?show_trend=true)](https://deepsource.io/gh/{{ user }}/{{ project }})

[![github/downloads](https://shields.io/github/downloads/{{ user }}/{{ project }}/total)](https://github.com/{{ user }}/{{ project }}/releases)
[![github/downloads/latest](https://shields.io/github/downloads/{{ user }}/{{ project }}/latest/total)](https://github.com/{{ user }}/{{ project }}/releases/latest)
[![github/issues](https://shields.io/github/issues/{{ user }}/{{ project }})](https://github.com/{{ user }}/{{ project }}/issues)
[![github/issues-closed](https://shields.io/github/issues-closed/{{ user }}/{{ project }})](https://github.com/{{ user }}/{{ project }}/issues?q=is%3Aissue+is%3Aclosed)
[![github/issues-pr](https://shields.io/github/issues-pr/{{ user }}/{{ project }})](https://github.com/{{ user }}/{{ project }}/pulls)
[![github/issues-pr-closed](https://shields.io/github/issues-pr-closed/{{ user }}/{{ project }})](https://github.com/{{ user }}/{{ project }}/pulls?q=is%3Apr+is%3Aclosed)
[![github/discussions](https://shields.io/github/discussions/{{ user }}/{{ project }})](https://github.com/{{ user }}/{{ project }}/discussions)
[![github/milestones](https://shields.io/github/milestones/all/{{ user }}/{{ project }})](https://github.com/{{ user }}/{{ project }}/milestones)
[![github/forks](https://shields.io/github/forks/{{ user }}/{{ project }})](https://github.com/{{ user }}/{{ project }}/network/members)
[![github/stars](https://shields.io/github/stars/{{ user }}/{{ project }})](https://github.com/{{ user }}/{{ project }}/stargazers)
[![github/watchers](https://shields.io/github/watchers/{{ user }}/{{ project }})](https://github.com/{{ user }}/{{ project }}/watchers)
[![github/contributors](https://shields.io/github/contributors/{{ user }}/{{ project }})](https://github.com/{{ user }}/{{ project }}/graphs/contributors)
[![github/commit-activity](https://shields.io/github/commit-activity/w/{{ user }}/{{ project }})](https://github.com/{{ user }}/{{ project }}/graphs/commit-activity)
[![github/last-commit](https://shields.io/github/last-commit/{{ user }}/{{ project }})](https://github.com/{{ user }}/{{ project }}/commits)
[![github/release-date](https://shields.io/github/release-date/{{ user }}/{{ project }})](https://github.com/{{ user }}/{{ project }}/releases/latest)

[![github/license](https://shields.io/github/license/{{ user }}/{{ project }})](https://github.com/{{ user }}/{{ project }}/blob/main/LICENSE)
[![github/languages](https://shields.io/github/languages/count/{{ user }}/{{ project }})](https://github.com/{{ user }}/{{ project }})
[![github/languages/top](https://shields.io/github/languages/top/{{ user }}/{{ project }})](https://github.com/{{ user }}/{{ project }})
[![github/directory-file-count](https://shields.io/github/directory-file-count/{{ user }}/{{ project }})](https://github.com/{{ user }}/{{ project }})
[![github/code-size](https://shields.io/github/languages/code-size/{{ user }}/{{ project }})](https://github.com/{{ user }}/{{ project }})
[![github/repo-size](https://shields.io/github/repo-size/{{ user }}/{{ project }})](https://github.com/{{ user }}/{{ project }})
[![github/v](https://shields.io/github/v/release/{{ user }}/{{ project }})](https://github.com/{{ user }}/{{ project }})

[![pypi/status](https://shields.io/pypi/status/{{ project }})](https://pypi.org/project/{{ project }}/#description)
[![pypi/v](https://shields.io/pypi/v/{{ project }})](https://pypi.org/project/{{ project }}/#history)
[![pypi/downloads](https://shields.io/pypi/dd/{{ project }})](https://pypi.org/project/{{ project }}/#files)
[![pypi/format](https://shields.io/pypi/format/{{ project }})](https://pypi.org/project/{{ project }}/#files)
[![pypi/implementation](https://shields.io/pypi/implementation/{{ project }})](https://pypi.org/project/{{ project }}/#files)
[![pypi/pyversions](https://shields.io/pypi/pyversions/{{ project }})](https://pypi.org/project/{{ project }}/#files)

A language server for {{ language }}.

- [x] [Document Link](https://microsoft.github.io/language-server-protocol/specifications/specification-current#textDocument_documentLink)
- [x] [Diagnostic](https://microsoft.github.io/language-server-protocol/specifications/specification-current#diagnostic)
- [x] [Hover](https://microsoft.github.io/language-server-protocol/specifications/specification-current#textDocument_hover)
- [x] [Completion](https://microsoft.github.io/language-server-protocol/specifications/specification-current#textDocument_completion)

## How Does It Work

See [here](https://github.com/neomutt/lsp-tree-sitter#usage).

See
[![readthedocs](https://shields.io/readthedocs/{{ project }})](https://{{ project }}.readthedocs.io)
to know more.
